% [Signal, Time, Setup, DateStamp, PlotParams] = pcscope(filename)
%
% Reads binary data from TXF data files
%   Input: 
%     filename   - PC Scope filename and path (matlab text string) 
%
%   Outputs: 
%     Signal     - Measurement signals (one channel per column)
%     Time       - Time vector for signals
%     Setup      - Mesurement setup parameters
%     DateStamp  - Date and time of measurement
%     PlotParams - Parameters used for plotting data
%
% If called without any return parameters the measurement signals will be plotted using 
% the limits that were applied when the measurement was saved.


function [Signal, Time, Setup, DateStamp, PlotParams]=pcscope(filename)
DateStamp=[];


% add default extension of 'PCS' if no extension is specified
pp=findstr(filename,'.');			
if (isempty(pp))
 filename=[deblank(filename),'.pcs'];
end
fid=fopen(deblank(filename),'rb','ieee-le');

strsize=26;
descrsize = 101;
charsize=104;
NumChan = 4;
gain=[0.5; 1; 2; 5; 10; 20; 50; 100; 1; 2; 5; 10; 20; 50; 100];

% read header data
Setup.Header      = char([fread(fid,strsize,'char')]');

if (strncmp(Setup.Header, 'PCSCOPE DATA FILE', 17))
 FileVersion       = fread(fid,1,'int32');
 Setup.Description = char([fread(fid,descrsize,'char')]');
 Setup.Tool        = char([fread(fid,descrsize,'char')]');
 Setup.Machine     = char([fread(fid,descrsize,'char')]');
 Setup.Enable      = fread(fid,NumChan,'int32');
 Setup.Antialias   = fread(fid,NumChan,'int32');
 Setup.Agnd        = fread(fid,NumChan,'int32');
 Setup.Icp         = fread(fid,NumChan,'int32');
 Setup.HighPass    = fread(fid,NumChan,'int32');
 index             = fread(fid,NumChan,'int32');
 Setup.Gain        = gain(index+1);
 clear index;
 Setup.Cal         = fread(fid,NumChan,'float32');

 Setup.Unit(1,:)   = char([fread(fid,strsize,'char')]');
 Setup.Unit(2,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(3,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(4,:)   = char([fread(fid,strsize,'char')]);  
 
 Setup.Name(1,:)   = char([fread(fid,strsize,'char')]');
 Setup.Name(2,:)   = char([fread(fid,strsize,'char')]);
 Setup.Name(3,:)   = char([fread(fid,strsize,'char')]);
 Setup.Name(4,:)   = char([fread(fid,strsize,'char')]);  

 Setup.TrigMethod  = fread(fid,1,'int32');
 Setup.TrigLevel   = fread(fid,1,'float32');
 Setup.TrigSlope   = fread(fid,1,'int32');
 Setup.TrigMode    = fread(fid,1,'int32');
 Setup.TrigSource  = fread(fid,1,'int32');
 Setup.TrigTimer   = fread(fid,1,'float32');
 Setup.TrigTimerUnits = fread(fid,1,'float32');
 Setup.SampFreq    = fread(fid,1,'float32');
 Setup.Decimate    = fread(fid,1,'int32');
 Setup.SampTime    = fread(fid,1,'float32');
 Setup.PretrigTime = fread(fid,1,'float32');

 Setup.Window      = fread(fid,NumChan,'int32');
 Setup.Integration = fread(fid,NumChan,'int32');

 Setup.Autoscale(1).min = fread(fid, 1, 'float64');
 Setup.Autoscale(1).max = fread(fid, 1, 'float64');
 Setup.Autoscale(2).min = fread(fid, 1, 'float64');
 Setup.Autoscale(2).max = fread(fid, 1, 'float64');
 Setup.Autoscale(3).min = fread(fid, 1, 'float64');
 Setup.Autoscale(3).max = fread(fid, 1, 'float64');
 Setup.Autoscale(4).min = fread(fid, 1, 'float64');
 Setup.Autoscale(4).max = fread(fid, 1, 'float64');

 Setup.FftSize    = fread(fid,1,'int32');
 Setup.Harmonics  = fread(fid,1,'int32');
 
 Setup.DataLogEnable   = fread(fid,1,'int32');
 Setup.DataLogLogFilename = char([fread(fid,512,'char')]');
 Setup.DataLogStartLogNum = fread(fid,1,'int32');
 Setup.DataLogLogDurationUnits = fread(fid,1,'int32');
 Setup.DataLogLogDurationfval = fread(fid,1,'float32');
 
 for i=1:10
    Setup.Filtertype(i)   = fread(fid,1,'int32');
    Setup.Filterorder(i)  = fread(fid,1,'int32');
    Setup.Filterfreq(i)   = fread(fid,1,'float32');
    Setup.Filterband(i)   = fread(fid,1,'float32');
    Setup.Filterharm(i)   = fread(fid,1,'int32');
    Setup.Filterchan(i)   = fread(fid,1,'int32');
 end
 
 DateStamp.Year        = fread(fid,1,'int16');
 DateStamp.Month       = fread(fid,1,'int16');
 DateStamp.Dayofweek   = fread(fid,1,'int16');
 DateStamp.Day         = fread(fid,1,'int16');
 DateStamp.Hour        = fread(fid,1,'int16');
 DateStamp.minute      = fread(fid,1,'int16');
 DateStamp.Second      = fread(fid,1,'int16');
 DateStamp.Millisecond = fread(fid,1,'int16');
 
 for i=1:4
 PlotParams.EnableAutoscale(i) = fread(fid,1,'int32');
 PlotParams.Xmin(i)= fread(fid,1,'float64');
 PlotParams.Xmax(i)= fread(fid,1,'float64');
 PlotParams.Xdiv(i)= fread(fid,1,'int32');
 PlotParams.Ymin(i)= fread(fid,1,'float64');
 PlotParams.Ymax(i)= fread(fid,1,'float64');
 PlotParams.Ydiv(i)= fread(fid,1,'int32');
 PlotParams.CursorIndex(i) = fread(fid,1,'int32');
 end

 for i=1:4
   ShowChan(i) = fread(fid,1,'uint32');
 end
 iFftStart(1)=fread(fid,1,'int32');
 iFftStart(2)=fread(fid,1,'int32');
 iFftWindow(1)=fread(fid,1,'int32');
 iFftWindow(2)=fread(fid,1,'int32');

elseif (strncmp(Setup.Header, 'PCSCOPE VER 5.0', 15))
 Setup.Description = char([fread(fid,descrsize,'char')]');
 Setup.Tool        = char([fread(fid,descrsize,'char')]');
 Setup.Machine     = char([fread(fid,descrsize,'char')]');
 Setup.Enable      = fread(fid,NumChan,'int32');
 Setup.Antialias   = fread(fid,NumChan,'int32');
 Setup.Agnd        = fread(fid,NumChan,'int32');
 Setup.Icp         = fread(fid,NumChan,'int32');
 Setup.HighPass    = fread(fid,NumChan,'int32');
 index             = fread(fid,NumChan,'int32');
 Setup.Gain        = gain(index+1);
 clear index;
 Setup.Cal         = fread(fid,NumChan,'float32');

 Setup.Unit(1,:)   = char([fread(fid,strsize,'char')]');
 Setup.Unit(2,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(3,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(4,:)   = char([fread(fid,strsize,'char')]);  
 
 Setup.Name(1,:)   = char([fread(fid,strsize,'char')]');
 Setup.Name(2,:)   = char([fread(fid,strsize,'char')]);
 Setup.Name(3,:)   = char([fread(fid,strsize,'char')]);
 Setup.Name(4,:)   = char([fread(fid,strsize,'char')]);  

 Setup.TrigMethod  = fread(fid,1,'int32');
 Setup.TrigLevel   = fread(fid,1,'float32');
 Setup.TrigSlope   = fread(fid,1,'int32');
 Setup.TrigMode    = fread(fid,1,'int32');
 Setup.TrigSource  = fread(fid,1,'int32');
 Setup.TrigTimer   = fread(fid,1,'float32');
 Setup.TrigTimerUnits = fread(fid,1,'float32');
 Setup.SampFreq    = fread(fid,1,'float32');
 Setup.Decimate    = fread(fid,1,'int32');
 Setup.SampTime    = fread(fid,1,'float32');
 Setup.PretrigTime = fread(fid,1,'float32');

 Setup.Window      = fread(fid,NumChan,'int32');
 Setup.Integration = fread(fid,NumChan,'int32');

 Setup.Autoscale(1).min = fread(fid, 1, 'float64');
 Setup.Autoscale(1).max = fread(fid, 1, 'float64');
 Setup.Autoscale(2).min = fread(fid, 1, 'float64');
 Setup.Autoscale(2).max = fread(fid, 1, 'float64');
 Setup.Autoscale(3).min = fread(fid, 1, 'float64');
 Setup.Autoscale(3).max = fread(fid, 1, 'float64');
 Setup.Autoscale(4).min = fread(fid, 1, 'float64');
 Setup.Autoscale(4).max = fread(fid, 1, 'float64');

 Setup.FftSize    = fread(fid,1,'int32');
 Setup.Harmonics  = fread(fid,1,'int32');
 
 Setup.DataLogEnable   = fread(fid,1,'int32');
 Setup.DataLogLogFilename = char([fread(fid,512,'char')]');
 Setup.DataLogStartLogNum = fread(fid,1,'int32');
 Setup.DataLogLogDurationUnits = fread(fid,1,'int32');
 Setup.DataLogLogDurationfval = fread(fid,1,'float32');
 
 for i=1:10
    Setup.Filtertype(i)   = fread(fid,1,'int32');
    Setup.Filterorder(i)  = fread(fid,1,'int32');
    Setup.Filterfreq(i)   = fread(fid,1,'float32');
    Setup.Filterband(i)   = fread(fid,1,'float32');
    Setup.Filterharm(i)   = fread(fid,1,'int32');
    Setup.Filterchan(i)   = fread(fid,1,'int32');
 end
 
 DateStamp.Year        = fread(fid,1,'int16');
 DateStamp.Month       = fread(fid,1,'int16');
 DateStamp.Dayofweek   = fread(fid,1,'int16');
 DateStamp.Day         = fread(fid,1,'int16');
 DateStamp.Hour        = fread(fid,1,'int16');
 DateStamp.minute      = fread(fid,1,'int16');
 DateStamp.Second      = fread(fid,1,'int16');
 DateStamp.Millisecond = fread(fid,1,'int16');
 
 for i=1:4
 PlotParams.EnableAutoscale(i) = fread(fid,1,'int32');
 PlotParams.Xmin(i)= fread(fid,1,'float64');
 PlotParams.Xmax(i)= fread(fid,1,'float64');
 PlotParams.Xdiv(i)= fread(fid,1,'int32');
 PlotParams.Ymin(i)= fread(fid,1,'float64');
 PlotParams.Ymax(i)= fread(fid,1,'float64');
 PlotParams.Ydiv(i)= fread(fid,1,'int32');
 PlotParams.CursorIndex(i) = fread(fid,1,'int32');
 end

 for i=1:4
   ShowChan(i) = fread(fid,1,'uint32');
 end
 iFftStart(1)=fread(fid,1,'int32');
 iFftStart(2)=fread(fid,1,'int32');
 iFftWindow(1)=fread(fid,1,'int32');
 iFftWindow(2)=fread(fid,1,'int32');
 
elseif (strncmp(Setup.Header, 'PCSCOPE VER 4.0', 15))
 Setup.Description = char([fread(fid,descrsize,'char')]');
 Setup.Tool        = char([fread(fid,descrsize,'char')]');
 Setup.Machine     = char([fread(fid,descrsize,'char')]');
 Setup.Enable      = fread(fid,NumChan,'int32');
 Setup.Antialias   = fread(fid,NumChan,'int32');
 Setup.Agnd        = fread(fid,NumChan,'int32');
 Setup.Icp         = fread(fid,NumChan,'int32');
 Setup.HighPass    = fread(fid,NumChan,'int32');
 
 index             = fread(fid,NumChan,'int32');
 Setup.Gain        = gain(index+1);
 clear index;
 Setup.Cal         = fread(fid,NumChan,'float32');

 Setup.Unit(1,:)   = char([fread(fid,strsize,'char')]');
 Setup.Unit(2,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(3,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(4,:)   = char([fread(fid,strsize,'char')]);  
 
 Setup.Name(1,:)   = char([fread(fid,strsize,'char')]');
 Setup.Name(2,:)   = char([fread(fid,strsize,'char')]);
 Setup.Name(3,:)   = char([fread(fid,strsize,'char')]);
 Setup.Name(4,:)   = char([fread(fid,strsize,'char')]);  

 Setup.TrigMethod  = fread(fid,1,'int32');
 Setup.TrigLevel   = fread(fid,1,'float32');
 Setup.TrigSlope   = fread(fid,1,'int32');
 Setup.TrigMode    = fread(fid,1,'int32');
 Setup.TrigSource  = fread(fid,1,'int32');
 Setup.SampFreq    = fread(fid,1,'float32');
 Setup.SampTime    = fread(fid,1,'float32');
 Setup.PretrigTime = fread(fid,1,'float32');

 Setup.Window      = fread(fid,NumChan,'int32');
 Setup.Integration = fread(fid,NumChan,'int32');

 Setup.Autoscale(1).min = fread(fid, 1, 'float64');
 Setup.Autoscale(1).max = fread(fid, 1, 'float64');
 Setup.Autoscale(2).min = fread(fid, 1, 'float64');
 Setup.Autoscale(2).max = fread(fid, 1, 'float64');
 Setup.Autoscale(3).min = fread(fid, 1, 'float64');
 Setup.Autoscale(3).max = fread(fid, 1, 'float64');
 Setup.Autoscale(4).min = fread(fid, 1, 'float64');
 Setup.Autoscale(4).max = fread(fid, 1, 'float64');

 Setup.FftSize    = fread(fid,1,'int32');
 Setup.Harmonics  = fread(fid,1,'int32');

 DateStamp.Year        = fread(fid,1,'int16');
 DateStamp.Month       = fread(fid,1,'int16');
 DateStamp.Dayofweek   = fread(fid,1,'int16');
 DateStamp.Day         = fread(fid,1,'int16');
 DateStamp.Hour        = fread(fid,1,'int16');
 DateStamp.minute      = fread(fid,1,'int16');
 DateStamp.Second      = fread(fid,1,'int16');
 DateStamp.Millisecond = fread(fid,1,'int16');

 PlotParams.Xmin(1)= fread(fid,1,'float64');
 PlotParams.Xmax(1)= fread(fid,1,'float64');
 PlotParams.Xdiv(1)= fread(fid,1,'int32');
 PlotParams.Ymin(1)= fread(fid,1,'float64');
 PlotParams.Ymax(1)= fread(fid,1,'float64');
 PlotParams.Ydiv(1)= fread(fid,1,'int32');
 PlotParams.Xmin(2)= fread(fid,1,'float64');
 PlotParams.Xmax(2)= fread(fid,1,'float64');
 PlotParams.Xdiv(2)= fread(fid,1,'int32');
 PlotParams.Ymin(2)= fread(fid,1,'float64');
 PlotParams.Ymax(2)= fread(fid,1,'float64');
 PlotParams.Ydiv(2)= fread(fid,1,'int32');

elseif (strncmp(Setup.Header, 'PCSCOPE VER 3.0', 15) | strncmp(Setup.Header, 'PCSCOPE VER 3.1', 15))
 Setup.Description = char([fread(fid,descrsize,'char')]');
 Setup.Tool        = char([fread(fid,descrsize,'char')]');
 Setup.Machine     = char([fread(fid,descrsize,'char')]');
 Setup.Enable      = fread(fid,NumChan,'int32');
 Setup.Antialias   = fread(fid,NumChan,'int32');
 index             = fread(fid,NumChan,'int32');
 Setup.Gain        = gain(index+1);
 clear index;
 Setup.Cal         = fread(fid,NumChan,'float32');

 Setup.Unit(1,:)   = char([fread(fid,strsize,'char')]');
 Setup.Unit(2,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(3,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(4,:)   = char([fread(fid,strsize,'char')]);  
 
 Setup.Name(1,:)   = char([fread(fid,strsize,'char')]');
 Setup.Name(2,:)   = char([fread(fid,strsize,'char')]);
 Setup.Name(3,:)   = char([fread(fid,strsize,'char')]);
 Setup.Name(4,:)   = char([fread(fid,strsize,'char')]);  

 Setup.TrigMethod  = fread(fid,1,'int32');
 Setup.TrigLevel   = fread(fid,1,'float32');
 Setup.TrigSlope   = fread(fid,1,'int32');
 Setup.TrigMode    = fread(fid,1,'int32');
 Setup.SampFreq    = fread(fid,1,'float32');
 Setup.SampTime    = fread(fid,1,'float32');
 Setup.PretrigTime = fread(fid,1,'float32');

 Setup.Window      = fread(fid,NumChan,'int32');
 Setup.Integration = fread(fid,NumChan,'int32');

 Setup.Autoscale(1).min = fread(fid, 1, 'float64');
 Setup.Autoscale(1).max = fread(fid, 1, 'float64');
 Setup.Autoscale(2).min = fread(fid, 1, 'float64');
 Setup.Autoscale(2).max = fread(fid, 1, 'float64');
 Setup.Autoscale(3).min = fread(fid, 1, 'float64');
 Setup.Autoscale(3).max = fread(fid, 1, 'float64');
 Setup.Autoscale(4).min = fread(fid, 1, 'float64');
 Setup.Autoscale(4).max = fread(fid, 1, 'float64');

 Setup.FftSize    = fread(fid,1,'int32');
 Setup.Harmonics  = fread(fid,1,'int32');

 DateStamp.Year        = fread(fid,1,'int16');
 DateStamp.Month       = fread(fid,1,'int16');
 DateStamp.Dayofweek   = fread(fid,1,'int16');
 DateStamp.Day         = fread(fid,1,'int16');
 DateStamp.Hour        = fread(fid,1,'int16');
 DateStamp.minute      = fread(fid,1,'int16');
 DateStamp.Second      = fread(fid,1,'int16');
 DateStamp.Millisecond = fread(fid,1,'int16');

 PlotParams.Xmin(1)= fread(fid,1,'float64');
 PlotParams.Xmax(1)= fread(fid,1,'float64');
 PlotParams.Xdiv(1)= fread(fid,1,'int32');
 PlotParams.Ymin(1)= fread(fid,1,'float64');
 PlotParams.Ymax(1)= fread(fid,1,'float64');
 PlotParams.Ydiv(1)= fread(fid,1,'int32');
 PlotParams.Xmin(2)= fread(fid,1,'float64');
 PlotParams.Xmax(2)= fread(fid,1,'float64');
 PlotParams.Xdiv(2)= fread(fid,1,'int32');
 PlotParams.Ymin(2)= fread(fid,1,'float64');
 PlotParams.Ymax(2)= fread(fid,1,'float64');
 PlotParams.Ydiv(2)= fread(fid,1,'int32');

elseif (strncmp(Setup.Header, 'PCSCOPE VER 2.0', 15))
 Setup.Description = char([fread(fid,descrsize,'char')]');
 Setup.Tool        = char([fread(fid,descrsize,'char')]');
 Setup.Machine     = char([fread(fid,descrsize,'char')]');
 Setup.Enable      = fread(fid,NumChan,'int32');
 Setup.Antialias   = fread(fid,NumChan,'int32');
 index             = fread(fid,NumChan,'int32');
 Setup.Gain        = gain(index+1);
 clear index;
 Setup.Cal         = fread(fid,NumChan,'float32');

 Setup.Unit(1,:)   = char([fread(fid,strsize,'char')]');
 Setup.Unit(2,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(3,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(4,:)   = char([fread(fid,strsize,'char')]);  
 
 Setup.TrigMethod  = fread(fid,1,'int32');
 Setup.TrigLevel   = fread(fid,1,'float32');
 Setup.TrigSlope   = fread(fid,1,'int32');
 Setup.TrigMode    = fread(fid,1,'int32');
 Setup.SampFreq    = fread(fid,1,'float32');
 Setup.SampTime    = fread(fid,1,'float32');
 Setup.PretrigTime = fread(fid,1,'float32');

 DateStamp.Year        = fread(fid,1,'int16');
 DateStamp.Month       = fread(fid,1,'int16');
 DateStamp.Dayofweek   = fread(fid,1,'int16');
 DateStamp.Day         = fread(fid,1,'int16');
 DateStamp.Hour        = fread(fid,1,'int16');
 DateStamp.minute      = fread(fid,1,'int16');
 DateStamp.Second      = fread(fid,1,'int16');
 DateStamp.Millisecond = fread(fid,1,'int16');

 PlotParams.Xmin(1)= fread(fid,1,'float64');
 PlotParams.Xmax(1)= fread(fid,1,'float64');
 PlotParams.Xdiv(1)= fread(fid,1,'int32');
 PlotParams.Ymin(1)= fread(fid,1,'float64');
 PlotParams.Ymax(1)= fread(fid,1,'float64');
 PlotParams.Ydiv(1)= fread(fid,1,'int32');
 PlotParams.Xmin(2)= fread(fid,1,'float64');
 PlotParams.Xmax(2)= fread(fid,1,'float64');
 PlotParams.Xdiv(2)= fread(fid,1,'int32');
 PlotParams.Ymin(2)= fread(fid,1,'float64');
 PlotParams.Ymax(2)= fread(fid,1,'float64');
 PlotParams.Ydiv(2)= fread(fid,1,'int32');
 
elseif (strncmp(Setup.Header, 'PCSCOPE VER 1.0', 15))
 Setup.Description = char([fread(fid,descrsize,'char')]');
 Setup.Enable      = fread(fid,NumChan,'int32');
 Setup.Antialias   = fread(fid,NumChan,'int32');
 index             = fread(fid,NumChan,'int32');
 Setup.Gain        = gain(index+1);
 clear index;
 Setup.Cal         = fread(fid,NumChan,'float32');

 Setup.Unit(1,:)   = char([fread(fid,strsize,'char')]');
 Setup.Unit(2,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(3,:)   = char([fread(fid,strsize,'char')]);
 Setup.Unit(4,:)   = char([fread(fid,strsize,'char')]);  
 
 Setup.TrigMethod  = fread(fid,1,'int32');
 Setup.TrigLevel   = fread(fid,1,'float32');
 Setup.TrigSlope   = fread(fid,1,'int32');
 Setup.TrigMode    = fread(fid,1,'int32');
 Setup.SampFreq    = fread(fid,1,'float32');
 Setup.SampTime    = fread(fid,1,'float32');
 Setup.PretrigTime = fread(fid,1,'float32');
end

% TimLen is set to NumSampPerChan and set active channels and number of channels
NumSampPerChan=fread(fid,1,'uint32')-1;
ActiveChans = find(Setup.Enable == 1);
NumChanSamp=length(ActiveChans);

Signal = [reshape(fread(fid,NumChanSamp*NumSampPerChan,'int16'),NumSampPerChan,NumChanSamp)]';
Signal = Signal' * diag((Setup.Cal(ActiveChans))./(Setup.Gain(ActiveChans))) / 409.6;
Time = [0:NumSampPerChan-1]'/Setup.SampFreq;

if (strncmp(Setup.Header, 'PCSCOPE DATA FILE', 17))
  for i=1:4
    Setup.SensorName(i,:)    = char([fread(fid,100,'char')]');
    Setup.UnitNumerator(i)   = fread(fid,1,'int32');
    Setup.UnitDenominator(i) = fread(fid,1,'int32');
    % Units for Sensors are in a zero based array:
    %  "mV", "V", "N", "lb", "oz", "mm"   , "cm"   , "m"   , "in"   , "ft",
    %  "mm/s" , "cm/s" , "m/s" , "in/s" , "ft/s", "mm/s", "cm/s", "m/s",
    %  "in/s", "ft/s","G"
  end
end

fclose(fid);

% if there are no return parameters, plot the data on screen with the same limits
% used when the measurement was saved
if nargout == 0
 hax = gca;

 % change plot colors
 MatlabColors = get(hax, 'ColorOrder');
 PCScopeColors = [0,0,255;255,0,0;0,180,80;255,0,255]/255;
 Samp = 1;
 for i=1:4
  if Setup.Enable(i) ~= 0
   MatlabColors(Samp,:) = PCScopeColors(i,:);
   Samp = Samp + 1;
  end
 end
 set(hax,'ColorOrder',MatlabColors);  

 % plot all channels on one plot
 plot(Time, Signal)
 grid

 hxl=xlabel('Time, s');
 htl=title(Setup.Description);


 % set font size
 set([hxl,htl,hax],'FontSize',12);

 zoom on

 % clear return parameters to prevent echoing to the terminal
 clear Signal Time Setup DateStamp PlotParams
end
end

